<?php

/**
 * @file
 * Support for processing rut fields in Migrate.
 *
 * @code
 * $this->addFieldMapping('field_rut', 'source_rut_complete');
 * @endcode
 *
 * @code
 * $this->addFieldMapping('field_rut', 'source_rut');
 * $this->addFieldMapping('field_rut:dv', 'source_dv');
 * @endcode
 *
 */

/**
 * Implements hook_migrate_api().
 */
function rut_field_migrate_api() {
  $api = array(
    'api' => 2,
    'field handlers' => array('MigrateRutFieldHandler'),
  );

  return $api;
}


class MigrateRutFieldHandler extends MigrateFieldHandler {
  public function __construct() {
    $this->registerTypes(array('rut_field'));
  }

  public function fields($type, $instance, $migration = NULL) {
    return array(
      'dv' => t('Subfield: The verifying digit.'),
    );
  }

  public function prepare($entity, array $field_info, array $instance, array $values) {
    $arguments = array();
    if (isset($values['arguments'])) {
      $arguments = $values['arguments'];
      unset($values['arguments']);
    }

    $language = $this->getFieldLanguage($entity, $field_info, $arguments);
    $values = array_filter($values);
    $migration = Migration::currentMigration();
    foreach ($values as $delta => $value) {
      if (isset($arguments['dv'])) {
        $rut = $value;
        $dv = '';
        if (!is_array($arguments['dv'])) {
          $dv = $arguments['dv'];
        }
        elseif (isset($arguments['dv'][$delta])) {
          $dv = $arguments['dv'][$delta];
        }
      }
      else {
        list($rut, $dv) = rut_separate_rut($value);
      }

      if (rut_validate_rut($rut, $dv)) {
        $return[$language][$delta] = array('value' => rut_formatter_rut($rut, $dv));
      }
      else {
        $migration->saveMessage(
          t('Value <em>@value</em> and dv <em>@dv</em> is not a valid Rut for field !field',
            array('@value' => $value, '@dv' => $dv, '!field' => $instance['field_name'])),
          Migration::MESSAGE_INFORMATIONAL);
      }
    }

    return isset($return) ? $return : NULL;
  }
}
